==> jc-1.4.0.tar.gz: gnu/java/net/protocol/ftp/FTPResponse.h <==
// public final class gnu.java.net.protocol.ftp.FTPResponse

// class file dependencies
// @dep_class b7b1dee11e57eaee gnu_java_net_protocol_ftp_FTPResponse
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_protocol_ftp_FTPResponse_H_
#define _JC_gnu_java_net_protocol_ftp_FTPResponse_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_FTPResponse$sub_refs	_jc_gnu_java_net_protocol_ftp_FTPResponse$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPResponse$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_FTPResponse$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPResponse$refs	_jc_gnu_java_net_protocol_ftp_FTPResponse$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPResponse$nonrefs	_jc_gnu_java_net_protocol_ftp_FTPResponse$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object	_jc_gnu_java_net_protocol_ftp_FTPResponse$object;

typedef const struct _jc_gnu_java_net_protocol_ftp_FTPResponse$vmethods	_jc_gnu_java_net_protocol_ftp_FTPResponse$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_FTPResponse$vtable	_jc_gnu_java_net_protocol_ftp_FTPResponse$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_FTPResponse$vtype	_jc_gnu_java_net_protocol_ftp_FTPResponse$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_FTPResponse$method$_init$206934d97c5ba451(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object *, jint, struct _jc_java_lang_String$object *);
extern void _jc_gnu_java_net_protocol_ftp_FTPResponse$method$_init$6942250b7402bc83(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object *, jint, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jint _jc_gnu_java_net_protocol_ftp_FTPResponse$method$getCode$126e5d5741406467(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_net_protocol_ftp_FTPResponse$method$getData$bbc608c204d64215(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_net_protocol_ftp_FTPResponse$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_FTPResponse$method_info$getCode$126e5d5741406467;
extern _jc_method _jc_gnu_java_net_protocol_ftp_FTPResponse$method_info$getData$bbc608c204d64215;
extern _jc_method _jc_gnu_java_net_protocol_ftp_FTPResponse$method_info$getMessage$13aaf240efc902b1;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_FTPResponse$vmethods {
	jint	(*getCode$126e5d5741406467)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object *);
	struct _jc_java_lang_String$object	*(*getData$bbc608c204d64215)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object *);
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object *);
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_FTPResponse$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_protocol_ftp_FTPResponse$vmethods	gnu_java_net_protocol_ftp_FTPResponse;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_FTPResponse$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_FTPResponse$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_FTPResponse$sub_refs {
	struct _jc_java_lang_String$object	*message;
	struct _jc_java_lang_String$object	*data;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_FTPResponse$refs {
    _jc_gnu_java_net_protocol_ftp_FTPResponse$sub_refs	gnu_java_net_protocol_ftp_FTPResponse;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_FTPResponse$sub_nonrefs {
	jint	code;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_FTPResponse$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_protocol_ftp_FTPResponse$sub_nonrefs	gnu_java_net_protocol_ftp_FTPResponse;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object {
	_jc_gnu_java_net_protocol_ftp_FTPResponse$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_FTPResponse$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_FTPResponse$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_FTPResponse$vtype _jc_gnu_java_net_protocol_ftp_FTPResponse$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_FTPResponse, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_FTPResponse$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_FTPResponse_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/ftp/FTPResponse.h <==
// public final class gnu.java.net.protocol.ftp.FTPResponse

// class file dependencies
// @dep_class b7b1dee11e57eaee gnu_java_net_protocol_ftp_FTPResponse
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_protocol_ftp_FTPResponse_H_
#define _JC_gnu_java_net_protocol_ftp_FTPResponse_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_FTPResponse$sub_refs	_jc_gnu_java_net_protocol_ftp_FTPResponse$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPResponse$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_FTPResponse$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPResponse$refs	_jc_gnu_java_net_protocol_ftp_FTPResponse$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPResponse$nonrefs	_jc_gnu_java_net_protocol_ftp_FTPResponse$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object	_jc_gnu_java_net_protocol_ftp_FTPResponse$object;

typedef const struct _jc_gnu_java_net_protocol_ftp_FTPResponse$vmethods	_jc_gnu_java_net_protocol_ftp_FTPResponse$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_FTPResponse$vtable	_jc_gnu_java_net_protocol_ftp_FTPResponse$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_FTPResponse$vtype	_jc_gnu_java_net_protocol_ftp_FTPResponse$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_FTPResponse$method$_init$206934d97c5ba451(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object *, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_ftp_FTPResponse$method$_init$6942250b7402bc83(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object *, jint, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_java_net_protocol_ftp_FTPResponse$method$getCode$126e5d5741406467(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_net_protocol_ftp_FTPResponse$method$getData$bbc608c204d64215(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_net_protocol_ftp_FTPResponse$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_FTPResponse$method_info$getCode$126e5d5741406467;
extern _jc_method _jc_gnu_java_net_protocol_ftp_FTPResponse$method_info$getData$bbc608c204d64215;
extern _jc_method _jc_gnu_java_net_protocol_ftp_FTPResponse$method_info$getMessage$13aaf240efc902b1;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_FTPResponse$vmethods {
	jint	(*getCode$126e5d5741406467)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getData$bbc608c204d64215)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_FTPResponse$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_protocol_ftp_FTPResponse$vmethods	gnu_java_net_protocol_ftp_FTPResponse;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_FTPResponse$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_FTPResponse$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_FTPResponse$sub_refs {
	struct _jc_java_lang_String$object	*message;
	struct _jc_java_lang_String$object	*data;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_FTPResponse$refs {
    _jc_gnu_java_net_protocol_ftp_FTPResponse$sub_refs	gnu_java_net_protocol_ftp_FTPResponse;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_FTPResponse$sub_nonrefs {
	jint	code;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_FTPResponse$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_protocol_ftp_FTPResponse$sub_nonrefs	gnu_java_net_protocol_ftp_FTPResponse;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object {
	_jc_gnu_java_net_protocol_ftp_FTPResponse$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_FTPResponse$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_FTPResponse$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_FTPResponse$vtype _jc_gnu_java_net_protocol_ftp_FTPResponse$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_FTPResponse, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_FTPResponse$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_FTPResponse_H_ */
